==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor.md <==
# AwsIoTThingHumiditySensor


```text
aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor
```

```text
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')
```



| Illustration | AwsIoTThingHumiditySensor | AwsIoTThingHumiditySensorCard | AwsIoTThingHumiditySensorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor.png) | ![illustration for AwsIoTThingHumiditySensor](../../../aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor.Local.png) | ![illustration for AwsIoTThingHumiditySensorCard](../../../aws-20210730/Resource/LoT/AwsIoTThingHumiditySensorCard.Local.png) | ![illustration for AwsIoTThingHumiditySensorGroup](../../../aws-20210730/Resource/LoT/AwsIoTThingHumiditySensorGroup.Local.png) |




## AwsIoTThingHumiditySensor

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensor
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensor('AwsIoTThingHumiditySensor', 'Aws Io T Thing Humidity Sensor', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensor
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensor('AwsIoTThingHumiditySensor', 'Aws Io T Thing Humidity Sensor', 'an optional tech label')
@enduml
```

## AwsIoTThingHumiditySensorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensorCard
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensorCard('AwsIoTThingHumiditySensorCard', 'Aws Io T Thing Humidity Sensor Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensorCard
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensorCard('AwsIoTThingHumiditySensorCard', 'Aws Io T Thing Humidity Sensor Card', 'an optional description')
@enduml
```

## AwsIoTThingHumiditySensorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensorGroup
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensorGroup('AwsIoTThingHumiditySensorGroup', 'Aws Io T Thing Humidity Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensorGroup
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensorGroup('AwsIoTThingHumiditySensorGroup', 'Aws Io T Thing Humidity Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor.md <==
# AwsIoTThingHumiditySensor


```text
aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor
```

```text
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')
```



| Illustration | AwsIoTThingHumiditySensor | AwsIoTThingHumiditySensorCard | AwsIoTThingHumiditySensorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor.png) | ![illustration for AwsIoTThingHumiditySensor](../../../aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor.Local.png) | ![illustration for AwsIoTThingHumiditySensorCard](../../../aws-20210730/Resource/LoT/AwsIoTThingHumiditySensorCard.Local.png) | ![illustration for AwsIoTThingHumiditySensorGroup](../../../aws-20210730/Resource/LoT/AwsIoTThingHumiditySensorGroup.Local.png) |




## AwsIoTThingHumiditySensor

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensor
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensor('AwsIoTThingHumiditySensor', 'Aws Io T Thing Humidity Sensor', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensor
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensor('AwsIoTThingHumiditySensor', 'Aws Io T Thing Humidity Sensor', 'an optional tech label')
@enduml
```

## AwsIoTThingHumiditySensorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensorCard
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensorCard('AwsIoTThingHumiditySensorCard', 'Aws Io T Thing Humidity Sensor Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensorCard
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensorCard('AwsIoTThingHumiditySensorCard', 'Aws Io T Thing Humidity Sensor Card', 'an optional description')
@enduml
```

## AwsIoTThingHumiditySensorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensorGroup
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensorGroup('AwsIoTThingHumiditySensorGroup', 'Aws Io T Thing Humidity Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingHumiditySensorGroup
include('aws-20210730/Resource/LoT/AwsIoTThingHumiditySensor')

' renders the element
AwsIoTThingHumiditySensorGroup('AwsIoTThingHumiditySensorGroup', 'Aws Io T Thing Humidity Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
